<?php

namespace Drupal\field_zip_file\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\field_zip_file\Plugin\Field\FieldType\ZipFileItem;

/**
 * Formatter that shows the file size in a human readable way.
 *
 * @FieldFormatter(
 *   id = "zip_file_iframe",
 *   label = @Translation("iFrame"),
 *   field_types = {
 *     "zip_file"
 *   }
 * )
 */
class ZipFileIFrame extends ZipFileBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    $options = parent::defaultSettings();

    $options['iframe_width'] = '100%';
    $options['iframe_height'] = '100vh';
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);

    $form['iframe_width'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Iframe width'),
      '#default_value' => $this->getSetting('iframe_width'),
      '#description' => $this->t('Sample: 100%'),
    ];

    $form['iframe_height'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Iframe height'),
      '#default_value' => $this->getSetting('iframe_height'),
      '#description' => $this->t('Sample: 100vh'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];

    foreach ($items as $delta => $item) {
      $elements[$delta] = $this->renderIframe($item);
    }

    return $elements;
  }

  /**
   * Render iframe.
   */
  protected function renderIframe(ZipFileItem $zip_file) {
    return [
      '#theme' => 'zip_file_iframe',
      '#url' => $this->getUrl($zip_file),
      '#iframe_width' => $this->getSetting('iframe_width') ? $this->getSetting('iframe_width') : '100%',
      '#iframe_height' => $this->getSetting('iframe_height') ? $this->getSetting('iframe_height') : '100%',
    ];
  }

}
